@@ -4,13 +4,13 @@ import io
 import base64
 import requests
 from os.path import join, dirname, isfile
-from dotenv import load_dotenv, set_key
+from dotenv import load_dotenv, set_key, unset_key, get_key
 
 import torch
 from torch.utils import model_zoo
 
 from .loggers import Logger
-from .settings import TEMP_DIR, ME_URL, CLIENTS_URL, MODELS_URL, JOBS_URL, SUBMISSIONS_URL, DATA_URL
+from .settings import TEMP_DIR, ME_URL, CLIENTS_URL, MODELS_URL, JOBS_URL, SUBMISSIONS_URL, DATA_URL, BASE_URL
 from .settings import system_info
 
 # Load environment variables
@@ -29,20 +29,41 @@ def login(username, password):
     :param password: Password
     :return dict: JSON response. 
     """
-    TOKEN = base64.b64encode(f'{username}:{password}'.encode()).decode()
-    if not isfile(env_file):
-        open(env_file, 'w')
+    res = requests.get(ME_URL, auth=(username, password))
+    if res.status_code == 200:
+        TOKEN = base64.b64encode(f'{username}:{password}'.encode()).decode()
+        if not isfile(env_file):
+            open(env_file, 'w')
 
-    set_key(env_file, 'FEDBIONET_TOKEN', TOKEN)
-    load_dotenv(dotenv_path=env_file)
+        set_key(env_file, 'FEDBIONET_TOKEN', TOKEN)
+        return res.json()
+    elif res.status_code in range(400, 500):
+        return res.json()
+    else:
+        raise ConnectionError('Connection seems not to be working')
 
 
 def get_auth():
-    load_dotenv(dotenv_path=env_file)
-    TOKEN = os.environ['FEDBIONET_TOKEN']
+    TOKEN = get_key(env_file, 'FEDBIONET_TOKEN')
     return tuple(base64.b64decode(TOKEN.encode()).decode().split(':'))
 
 
+def logout():
+    unset_key(env_file, 'FEDBIONET_TOKEN')
+    load_dotenv(dotenv_path=env_file)
+
+
+def is_logged_in():
+    """ Checks if user data exists"""
+    try:
+        res = requests.get(ME_URL, auth=get_auth())
+        assert res.status_code == 200, 'Login validation failed.'
+        return True
+    except Exception as e:
+        logout()
+        return False
+
+
 def get_uuid_from_url(url):
     """
     Extract the uuid of an object from the URL.
